Containers of Patterns
========================

Containers of patterns are themselves patterns, and so can
contain instantiations of themselves.

Dictionaries of Patterns
---------------------------
.. autoclass:: paragami.pattern_containers.PatternDict
  :members:


Arrays of Patterns
---------------------------
.. autoclass:: paragami.pattern_containers.PatternArray
  :members:
